@@ -8,7 +8,4 @@ __version__ = '0.1.0'
 __author__  = 'Attasuntorn Traisuwan'
 
 
-# Bring in subpackages
-
-from pypath import transform
-from pypath import stain_extractor
\ No newline at end of file
+# Bring in subpackages
\ No newline at end of file
