@@ -1,9 +1,10 @@
 import spams
 import numpy as np
+import staintools
 from pypath.transform import convert_RGB_to_OD, convert_OD_to_RGB
 
 
-def color_decon(I_RGB):
+def HE_color_decon(I_RGB):
    ''' 
    matrix Factorization using spams library
    from A. Vahadane et al. 'Structure-Preserving Color Normalization and Sparse Stain Separation for Histological Images'
@@ -30,4 +31,15 @@ def color_decon(I_RGB):
    vdAs  = Hs_vec[:,1]*D[:,1].reshape((1,3))
    I_E   = convert_OD_to_RGB(vdAs).reshape(I_RGB.shape)
 
-   return I_H, I_E
\ No newline at end of file
+   return I_H, I_E
+
+def IHC_color_decon(I_RGB):
+   '''
+   Immunohistrochemistry color deconvolution
+   Using same technique as H&E image
+   input: I_RGB
+   output: I_DAB, I_H
+   '''
+   color_img = staintools.LuminosityStandardizer.standardize(I_RGB)
+   h, dab    = HE_color_decon(color_img)
+   return dab, h
\ No newline at end of file
